#
# spec file for package python-gsw
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%define skip_python36 1
Name:           python-gsw
Version:        3.6.18
Release:        1.3
Summary:        Gibbs Seawater Oceanographic Package of TEOS-10
# Note: Python code is MIT licensed
# C-code IS BSD-3-Clause licensed (see src/c_gsw/LICENSE)
# MATLAB function names and documentation are BSD-3-Clause licensed (see http://teos-10.org/pubs/gsw/html/gsw_licence.html)
License:        BSD-3-Clause AND MIT
Group:          Development/Languages/Python
URL:            https://github.com/TEOS-10/GSW-python
# gh#TEOS-10/GSW-Python#39 -- Tests are not included in the source tarball
Source0:        https://github.com/TEOS-10/GSW-Python/archive/v%{version}.tar.gz
BuildRequires:  %{python_module devel >= 3.5}
BuildRequires:  %{python_module numpy-devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
Requires:       python-numpy
# SECTION tests
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pandas}
# /SECTION
%python_subpackages

%description
Python implementation of the Thermodynamic Equation of
Seawater 2010 (TEOS-10).

%prep
%setup -q -n GSW-Python-%{version}

%build
CFLAGS="%{optflags}"
%ifarch i586 armv7l
CFLAGS="$CFLAGS -ffloat-store"
%endif
export CFLAGS
%python_build

%install
%python_install
%{python_expand %fdupes %{buildroot}%{$python_sitearch}}

%check
%pytest_arch ${donttest:+-k "not (${donttest:4})"}

%files %{python_files}
%doc README.md
%license LICENSE.txt
%{python_sitearch}/gsw
%{python_sitearch}/gsw-*.egg-info

%changelog
* Tue May 28 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 3.6.18
  * Avoid distutils by @ocefpaf in #143
  * Add citation in README.md by @rcaneill in #145
  * Fix upload-download artifacts by @ocefpaf in #154
  * Should fix PyPI publishing by @ocefpaf in #155
  * Version everything and allow tests to run on macos-14 by @ocefpaf in #159
  * Test on py312 by @ocefpaf in #164
  * Fix typo... by @ocefpaf in #163
  * Dev notes by @ocefpaf in #133
  * Remove used dependency by @ocefpaf in #165
  * Test against numpy 2.0 by @ocefpaf in #166
* Fri May 10 2024 Markéta Machová <mmachova@suse.com>
- Update to 3.6.17
  * Add 'const' modifiers to ufuncs via make_ufuncs.py
  * Ensure the slice is an array
  * Add gibbs and gibbs_ice via ufunc wrapping
* Thu Oct 13 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 3.6.16:
  * Update underlying c code to v3.06.16 #107
- Skipped update to 3.4.2:
  * add DOI by @ocefpaf in #72
  * Use GitHub Actions for the tests by @ocefpaf in #73
  * build wheel for Python 3.9 by @ocefpaf in #79
  * Wrap longitude, 0-360, where it is used directly. by @efiring in #86
  * Add link to new xarray wrapper gsw-xarray by @rcaneill in #87
  * Add py310 test to the test matrix... by @ocefpaf in #88
  * needs to avoid globing them before the autidwheel by @ocefpaf in #80
  * add pre-commit by @ocefpaf in #77
  * publish docs with GHA by @ocefpaf in #89
  * use micromamba in tests by @ocefpaf in #93
  * Fix teos 10 url by @ocefpaf in #94
  * Correct Nsquared unit by @rcaneill in #91
  * use np.expand_dims instead of np.newaxis by @rcaneill in #96
  * Add consts to PyUFuncGenericFunction declarations by @hoodmane in #99
  * Move to cibuildwheels by @ocefpaf in #100
  * remove unused file by @ocefpaf in #102
  * Rename master to main in the CIs by @ocefpaf in #105
  * update README by @ocefpaf in #104
  * Run every PR but publish only when tags by @ocefpaf in #106
- Skipped update to 3.4.1:
  * Add DOI
- Enable again tests skipped on aarch64 since fixed upstream
* Sun Feb 21 2021 Ben Greiner <code@bnavigator.de>
- Skip python36 build: With NumPy 1.20, python36-numpy is no
  longer available in Tumbleweed (NEP 29)
* Sun Jan 17 2021 Benjamin Greiner <code@bnavigator.de>
- Fix macro expansion for pytest call
* Thu Nov 12 2020 Marketa Machova <mmachova@suse.com>
- update to 3.4.0
  * Support for xarray DataArray
* Thu Aug 20 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix build on aarch64 by ignoring test_check_function[cfcf72]
  See: gh#TEOS-10/GSW-Python#40
* Wed Apr 24 2019 pgajdos@suse.com
- version update to 3.3.1
  * Add optional args to p_from_z and z_from_p (#49).
- github tar ball forever (#39)
* Wed Feb 20 2019 Matej Cepl <mcepl@suse.com>
- Update to 3.3.0:
  * Adds functions SP_salinometer, O2sol, and O2sol_SP_pt by
    updating the C source.
  * Fixes a bug in handling of p_ref in geostrophy.
  * Fixes a bug in distance when the pressure argument is
    omitted.
- Actually gh#TEOS-10/GSW-Python#40 can be worked around by
  adding -ffloat-store to CFLAGS. Which I do now for i586 and
  armv7l platforms.
* Thu Jul 26 2018 mcepl@suse.com
- Switch off test_check_function[cfcf71], which fails on 32bit archs
  (gh#TEOS-10/GSW-Python#40).
* Thu Jul 26 2018 mcepl@suse.com
- Clean SPEC
- Remove gsw_licence.html (license is inside the distribution tarball)
- Add tests.tar.gz with tests from the upstream git repository and
  enable tests
* Sat Jun  2 2018 sebix+novell.com@sebix.at
- update to version 3.2.1, no changelog available, listing
  relevant git commits:
  * Fix bug in pchip_interp utility function. (#27)
  A smoke test has been added for this function.
  The function is an additional wrapper around the wrapped ufunc,
  the core of which is in C, and it is not used internally.
  * Make the code c/c++ compatible; eliminate source duplication. (#28)
  * Cleanup: warnings and last reference to src2. (#32)
  * This is a minor cleanup of the code generators and associated C.
* Fri Mar  2 2018 sebix+novell.com@sebix.at
- update to version 3.2.0
  * no changelog available
- remove check boundary condition
- use %%license macro
- convert to singlespec and deactivate python2
- use fdupes
* Wed Jul 12 2017 toddrme2178@gmail.com
- Initial version
